#
# Conditional build:
%bcond_with	apidocs		# do not build and package API docs
%bcond_with	systemd		# systemd
#
Summary:	Library and proxy module for properly loading and sharing PKCS#11 modules
Summary(pl.UTF-8):	Biblioteka i moduł proxy do właściwego wczytywania i współdzielenia modułów PKCS#11
Name:		p11-kit
Version:	0.24.1
Release:	2%{?tld}
License:	BSD
Group:		Libraries
#Source0Download: https://github.com/p11-glue/p11-kit/releases
Source0:	https://github.com/p11-glue/p11-kit/releases/download/%{version}/%{name}-%{version}.tar.xz
# Source0-md5:	67b2539bdca6b4bedaeecc12864d2796
URL:		https://p11-glue.github.io/p11-glue/p11-kit.html
BuildRequires:	gettext-tools >= 0.19.8
%{?with_apidocs:BuildRequires:	gtk-doc >= 1.15}
BuildRequires:	libffi-devel >= 3.0.0
BuildRequires:	libtasn1-devel >= 2.14
BuildRequires:	libxslt-progs
BuildRequires:	pkgconfig >= 1:0.29
BuildRequires:	pkgconfig(libffi) >= 3.0.0
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpmbuild(macros) >= 2.011
%{?with_systemd:BuildRequires:	systemd-devel >= 1:209}
BuildRequires:	tar >= 1:1.22
BuildRequires:	xz
Requires(post,preun):	systemd-units >= 1:250.1
Requires:	filesystem >= 4.0-28
Requires:	libtasn1 >= 2.14
Requires:	systemd-units >= 1:250.1
Suggests:	ca-certificates
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
P11-KIT provides a way to load and enumerate PKCS#11 modules. It also
provides a standard configuration setup for installing PKCS#11 modules
in such a way that they-re discoverable.

%description -l pl.UTF-8
P11-KIT zapewnia możliwość ładowania i numeracji modułów PKCS#11.
Zapewnia też ustandaryzowaną konfigurację do instalowania modułów
PKCS#11 w taki sposób, żeby były możliwe do wykrycia.

%package devel
Summary:	Header files for P11-KIT library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki P11-KIT
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Obsoletes:	p11-kit-static < 0.9

%description devel
Header files for P11-KIT library.

%description devel -l pl.UTF-8
Pliki nagłówkowe biblioteki P11-KIT.

%package apidocs
Summary:	P11-KIT API documentation
Summary(pl.UTF-8):	Dokumentacja API biblioteki P11-KIT
Group:		Documentation
Requires:	gtk-doc-common
BuildArch:	noarch

%description apidocs
API and internal documentation for P11-KIT library.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki P11-KIT.

%package -n bash-completion-p11-kit
Summary:	Bash completion for p11-kit commands
Summary(pl.UTF-8):	Bashowe uzupełnianie parametrów poleceń p11-kit
Group:		Applications/Shells
Requires:	%{name} = %{version}-%{release}
Requires:	bash-completion >= 2.0
BuildArch:	noarch

%description -n bash-completion-p11-kit
Bash completion for p11-kit commands (p11-kit and trust).

%description -n bash-completion-p11-kit -l pl.UTF-8
Bashowe uzupełnianie parametrów poleceń p11-kit (p11-kit i trust).

%prep
%setup -q

%build
%configure \
	bashcompdir=%{bash_compdir} \
	%{!?with_apidocs:--disable-doc} \
	--disable-silent-rules \
	%{!?with_systemd:--without-systemd} \
	--with-html-dir=%{_gtkdocdir} \
	--with-trust-paths=/etc/certs/ca-certificates.crt
%{__make}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT%{_sysconfdir}/pkcs11/modules

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

# obsoleted by pkg-config
%{__rm} $RPM_BUILD_ROOT%{_libdir}/libp11-kit.la
# dlopened module
%{__rm} $RPM_BUILD_ROOT%{_libdir}/pkcs11/*.la

%{__mv} $RPM_BUILD_ROOT%{_sysconfdir}/pkcs11/pkcs11.conf{.example,}

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/ldconfig
%systemd_user_post p11-kit-server.service p11-kit-server.socket

%preun
%systemd_user_preun p11-kit-server.service p11-kit-server.socket

%postun	-p /sbin/ldconfig

%files
%exclude_systemd_files
%defattr(644,root,root,755)
%doc AUTHORS COPYING ChangeLog NEWS README
%attr(755,root,root) %{_bindir}/p11-kit
%attr(755,root,root) %{_bindir}/trust
%attr(755,root,root) %{_libdir}/libp11-kit.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libp11-kit.so.0
%attr(755,root,root) %{_libdir}/p11-kit-proxy.so
%dir %{_sysconfdir}/pkcs11
%dir %{_sysconfdir}/pkcs11/modules
%config(noreplace) %verify(not md5 mtime size) %{_sysconfdir}/pkcs11/pkcs11.conf
%attr(755,root,root) %{_libdir}/pkcs11/p11-kit-client.so
%attr(755,root,root) %{_libdir}/pkcs11/p11-kit-trust.so
%dir %{_libexecdir}/p11-kit
%attr(755,root,root) %{_libexecdir}/p11-kit/p11-kit-remote
%attr(755,root,root) %{_libexecdir}/p11-kit/p11-kit-server
%attr(755,root,root) %{_libexecdir}/p11-kit/trust-extract-compat
%dir %{_datadir}/p11-kit
%dir %{_datadir}/p11-kit/modules
%{_datadir}/p11-kit/modules/p11-kit-trust.module
%if %{with systemd}
%{systemduserunitdir}/p11-kit-server.service
%{systemduserunitdir}/p11-kit-server.socket
%endif

%files devel
%exclude_systemd_files
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libp11-kit.so
%{_includedir}/p11-kit-1
%{_pkgconfigdir}/p11-kit-1.pc

%if %{with apidocs}
%files apidocs
%exclude_systemd_files
%defattr(644,root,root,755)
%{_gtkdocdir}/p11-kit
%endif

%files -n bash-completion-p11-kit
%exclude_systemd_files
%defattr(644,root,root,755)
%{bash_compdir}/p11-kit
%{bash_compdir}/trust
%changelog
* Thu Dec 14 2023 TLD Linux <feedback@tld-linux.org>
- For complete changelog see: http://git.tld-linux.org/?p=packages/p11-kit.git;a=log;h=master

* Thu Dec 14 2023 Marcin Krol <hawk@tld-linux.org> 8ab1fc1
- allow building on systems without systemd, fixed docs configure option

* Sun Feb 12 2023 Jakub Bogusz <qboosh@pld-linux.org> e0aa142
- release 2 (libffi 3.4.x)

* Wed Sep 07 2022 Jakub Bogusz <qboosh@pld-linux.org> 9b1ca85
- versioned Obsoletes

* Thu Mar 17 2022 Jakub Bogusz <qboosh@pld-linux.org> ece50ac
- updated to 0.24.1

* Sun Feb 27 2022 Marcin Krol <hawk@tld-linux.org> d3b1795
- BR gtk-doc only with apidocs enabled

* Sun Jan 09 2022 Jan Rękorajski <baggins@pld-linux.org> 119a369
- add systemd user service startup, rel 3

* Sat Nov 20 2021 Jan Rękorajski <baggins@pld-linux.org> bf54e5a
- rebuild with separate debuginfo build-ids

* Wed Mar 31 2021 Jakub Bogusz <qboosh@pld-linux.org> b297801
- updated to 0.23.22 (fixes CVE-2020-29361, CVE-2020-29362, CVE-2020-29363)
- added bash-completion- package

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> cb6f79f
- unconditional noarch subpackages

* Thu Sep 10 2020 Jakub Bogusz <qboosh@pld-linux.org> af323cc
- updated to 0.23.21

* Mon Apr 20 2020 Jan Rękorajski <baggins@pld-linux.org> b78a9ed
- really rebuild with libffi 3.3
- release 3 (by relup.sh)

* Mon Apr 20 2020 Jan Rękorajski <baggins@pld-linux.org> db5f820
- rebuild with libffi 3.3
- release 2 (by relup.sh)

* Sun Apr 12 2020 Jakub Bogusz <qboosh@pld-linux.org> b10d986
- updated to 0.23.20

* Mon Sep 30 2019 Jakub Bogusz <qboosh@pld-linux.org> 8df572a
- updated to 0.23.18.1

* Wed Sep 11 2019 Jakub Bogusz <qboosh@pld-linux.org> c9bdde9
- updated to 0.23.17

* Sun Jun 02 2019 Jakub Bogusz <qboosh@pld-linux.org> 1558d49
- updated to 0.23.16.1

* Tue Feb 12 2019 Jakub Bogusz <qboosh@pld-linux.org> 915bb3c
- updated to 0.23.15

* Thu Aug 30 2018 Jakub Bogusz <qboosh@pld-linux.org> 63053cc
- updated to 0.23.14

* Wed Apr 11 2018 Jakub Bogusz <qboosh@pld-linux.org> fcee059
- honour _libexecdir; release 2

* Wed Apr 11 2018 Jakub Bogusz <qboosh@pld-linux.org> 428f7f5
- new URL, updated to 0.23.10

